@@ -1,7 +1,7 @@
 /*
  gg_xml.h -- Gaia common support for XML documents
   
- version 4.1, 2013 May 8
+ version 5.0, 2020 August 1
 
  Author: Sandro Furieri a.furieri@lqt.it
 
@@ -23,7 +23,7 @@ The Original Code is the SpatiaLite library
 
 The Initial Developer of the Original Code is Alessandro Furieri
  
-Portions created by the Initial Developer are Copyright (C) 2008-2013
+Portions created by the Initial Developer are Copyright (C) 2008-2021
 the Initial Developer. All Rights Reserved.
 
 Contributor(s):
@@ -66,7 +66,9 @@ extern "C"
 /** XmlBLOB internal marker: END */
 #define GAIA_XML_END		0xDD
 /** XmlBLOB internal marker: HEADER */
-#define GAIA_XML_HEADER		0xAB
+#define GAIA_XML_HEADER		0xAC
+/** XmlBLOB internal marker: LEGACY HEADER */
+#define GAIA_XML_LEGACY_HEADER	0xAB
 /** XmlBLOB internal marker: SCHEMA */
 #define GAIA_XML_SCHEMA		0xBA
 /** XmlBLOB internal marker: FILEID */
@@ -74,6 +76,8 @@ extern "C"
 /** XmlBLOB internal marker: PARENTID */
 #define GAIA_XML_PARENTID	0xDA
 /** XmlBLOB internal marker: TITLE */
+#define GAIA_XML_NAME		0xDE
+/** XmlBLOB internal marker: TITLE */
 #define GAIA_XML_TITLE		0xDB
 /** XmlBLOB internal marker: ABSTRACT */
 #define GAIA_XML_ABSTRACT	0xDC
@@ -98,8 +102,14 @@ extern "C"
 #define GAIA_XML_SLD_SE_RASTER_STYLE	0x10
 /** XmlBLOB FLAG - SLDSE VECTOR STYLE bitmask */
 #define GAIA_XML_SLD_SE_VECTOR_STYLE	0x40
+/** XmlBLOB FLAG - SLD STYLE bitmask */
+#define GAIA_XML_SLD_STYLE		0x48
 /** XmlBLOB FLAG - SVG bitmask */
 #define GAIA_XML_SVG			0x20
+/** XmlBLOB FLAG - GPX bitmask */
+#define GAIA_XML_GPX			0x08
+/** XmlBLOB FLAG - MapConfig bitmask */
+#define GAIA_XML_MAP_CONFIG		0x88
 
 
 /* function prototypes */
@@ -127,7 +137,7 @@ extern "C"
  \param xml_len lenght of the XML document (in bytes).
  \param compressed if TRUE the returned XmlBLOB will be zip-compressed.
  \param schemaURI if not NULL the XML document will be assumed to be valid
-  only if it succesfully passes a formal Schema valitadion.
+  only if it successfully passes a formal Schema valitadion.
  \param result on completion will containt a pointer to XmlBLOB:
  NULL on failure.
  \param size on completion this variable will contain the XmlBLOB's size (in bytes)
@@ -143,9 +153,9 @@ extern "C"
  so you are responsible to free() it [unless SQLite will take care
  of memory cleanup via buffer binding].
  */
-    GAIAGEO_DECLARE void gaiaXmlToBlob (void *p_cache, const unsigned char *xml,
-					int xml_len, int compressed,
-					const char *schemaURI,
+    GAIAGEO_DECLARE void gaiaXmlToBlob (const void *p_cache,
+					const unsigned char *xml, int xml_len,
+					int compressed, const char *schemaURI,
 					unsigned char **result, int *size,
 					char **parsing_errors,
 					char **schema_validation_errors);
@@ -185,7 +195,7 @@ extern "C"
  means that the whole XML Document will consist of a single line.
  \param result pointer to the memory buffer containing the XML Document
  \param res_size dimension (in bytes) of the XML Document memory buffer
- (both values will be passed back after succesful completion).
+ (both values will be passed back after successful completion).
 
 
  \sa gaiaXmlToBlob, gaiaXmlTextFromBlob
@@ -211,7 +221,8 @@ extern "C"
 
  \sa gaiaIsCompressedXmlBlob, gaiaIsSchemaValidatedXmlBlob, 
  gaiaIsIsoMetadataXmlBlob, gaiaIsSldSeVectorStyleXmlBlob, 
- gaiaIsSldSeRasterStyleXmlBlob, gaiaIsSvgXmlBlob
+ gaiaIsSldSeRasterStyleXmlBlob, gaiaIsSldStyleXmlBlob,
+ gaiaIsSvgXmlBlob, gaiaIsGpxXmlBlob, gaiaIsMapConfigXmlBlob
  */
     GAIAGEO_DECLARE int gaiaIsValidXmlBlob (const unsigned char *blob,
 					    int size);
@@ -226,7 +237,8 @@ extern "C"
 
  \sa gaiaIsValidXmlBlob, gaiaIsSchemaValidatedXmlBlob, 
  gaiaIsIsoMetadataXmlBlob, gaiaIsSldSeVectorStyleXmlBlob, 
- gaiaIsSldSeRasterStyleXmlBlob, gaiaIsSvgXmlBlob
+ gaiaIsSldSeRasterStyleXmlBlob, gaiaIsSldStyleXmlBlob,
+ gaiaIsSvgXmlBlob, gaiaIsGpxXmlBlob, gaiaIsMapConfigXmlBlob
  */
     GAIAGEO_DECLARE int gaiaIsCompressedXmlBlob (const unsigned char *blob,
 						 int size);
@@ -241,7 +253,8 @@ extern "C"
 
  \sa gaiaIsValidXmlBlob, gaiaIsSchemaValidatedXmlBlob, 
  gaiaIsCompressedXmlBlob, gaiaIsSldSeVectorStyleXmlBlob, 
- gaiaIsSldSeRasterStyleXmlBlob, gaiaIsSvgXmlBlob
+ gaiaIsSldSeRasterStyleXmlBlob, gaiaIsSldStyleXmlBlob,
+ gaiaIsSvgXmlBlob, gaiaIsGpxXmlBlob, gaiaIsMapConfigXmlBlob
  */
     GAIAGEO_DECLARE int gaiaIsIsoMetadataXmlBlob (const unsigned char *blob,
 						  int size);
@@ -252,11 +265,12 @@ extern "C"
  \param blob pointer to the XmlBLOB buffer.
  \param size XmlBLOB's size (in bytes).
 
- \return TRUE or FALSE if the BLOB actually is a valid XmlBLOB; -1 in any other case.
+ \return TRUE or FALSE if the BLOB actually is a valid XmlBLOB of the 
+ Vector type; -1 in any other case.
 
  \sa gaiaIsValidXmlBlob, gaiaIsSchemaValidatedXmlBlob, 
  gaiaIsCompressedXmlBlob, gaiaIsIsoMetadataXmlBlob, 
- gaiaIsSldSeRasterStyleXmlBlob, gaiaIsSvgXmlBlob
+ gaiaIsSldSeRasterStyleXmlBlob, gaiaIsSvgXmlBlob, gaiaIsGpxXmlBlob
  */
     GAIAGEO_DECLARE int gaiaIsSldSeVectorStyleXmlBlob (const unsigned char
 						       *blob, int size);
@@ -267,15 +281,51 @@ extern "C"
  \param blob pointer to the XmlBLOB buffer.
  \param size XmlBLOB's size (in bytes).
 
- \return TRUE or FALSE if the BLOB actually is a valid XmlBLOB; -1 in any other case.
+ \return TRUE or FALSE if the BLOB actually is a valid XmlBLOB of the
+ Raster type; -1 in any other case.
 
  \sa gaiaIsValidXmlBlob, gaiaIsSchemaValidatedXmlBlob, 
  gaiaIsCompressedXmlBlob, gaiaIsIsoMetadataXmlBlob, 
- gaiaIsSldSeVectorStyleXmlBlob, gaiaIsSvgXmlBlob
+ gaiaIsSldSeVectorStyleXmlBlob, gaiaIsSldStyleXmlBlob,
+ gaiaIsSvgXmlBlob, gaiaIsGpxXmlBlob, gaiaIsMapConfigXmlBlob
  */
     GAIAGEO_DECLARE int gaiaIsSldSeRasterStyleXmlBlob (const unsigned char
 						       *blob, int size);
 
+/**
+ Checks if a valid XmlBLOB buffer does contain an SLD Style or not
+
+ \param blob pointer to the XmlBLOB buffer.
+ \param size XmlBLOB's size (in bytes).
+
+ \return TRUE or FALSE if the BLOB actually is a valid XmlBLOB of the
+ SLD type; -1 in any other case.
+
+ \sa gaiaIsValidXmlBlob, gaiaIsSchemaValidatedXmlBlob, 
+ gaiaIsCompressedXmlBlob, gaiaIsIsoMetadataXmlBlob, 
+ gaiaIsSldSeVectorStyleXmlBlob, gaiaIsSldSeRasterXmlBlob,
+ gaiaIsSvgXmlBlob, gaiaIsGpxXmlBlob, gaiaIsMapConfigXmlBlob
+ */
+    GAIAGEO_DECLARE int gaiaIsSldStyleXmlBlob (const unsigned char
+					       *blob, int size);
+
+/**
+ Checks if a valid XmlBLOB buffer does contain a MapConfig or not
+
+ \param blob pointer to the XmlBLOB buffer.
+ \param size XmlBLOB's size (in bytes).
+
+ \return TRUE or FALSE if the BLOB actually is a valid XmlBLOB of the
+ MapConfig type; -1 in any other case.
+
+ \sa gaiaIsValidXmlBlob, gaiaIsSchemaValidatedXmlBlob, 
+ gaiaIsCompressedXmlBlob, gaiaIsIsoMetadataXmlBlob, 
+ gaiaIsSldSeVectorStyleXmlBlob, gaiaIsSldSeRasterXmlBlob,
+ gaiaIsSvgXmlBlob, gaiaIsGpxXmlBlob, gaiaIsSldStyleXmlBlob
+ */
+    GAIAGEO_DECLARE int gaiaIsMapConfigXmlBlob (const unsigned char
+						*blob, int size);
+
 /**
  Checks if a valid XmlBLOB buffer does contain an SVG Symbol or not
 
@@ -286,10 +336,26 @@ extern "C"
 
  \sa gaiaIsValidXmlBlob, gaiaIsSchemaValidatedXmlBlob, 
  gaiaIsCompressedXmlBlob, gaiaIsIsoMetadataXmlBlob, 
- gaiaIsSldSeVectorStyleXmlBlob, gaiaIsSldSeRasterStyleXmlBlob
+ gaiaIsSldSeVectorStyleXmlBlob, gaiaIsSldStyleXmlBlob,
+ gaiaIsSldSeRasterStyleXmlBlob, gaiaIsGpxXmlBlob, gaiaIsMapConfigXmlBlob
  */
     GAIAGEO_DECLARE int gaiaIsSvgXmlBlob (const unsigned char *blob, int size);
 
+/**
+ Checks if a valid XmlBLOB buffer does contain a GPX document or not
+
+ \param blob pointer to the XmlBLOB buffer.
+ \param size XmlBLOB's size (in bytes).
+
+ \return TRUE or FALSE if the BLOB actually is a valid XmlBLOB; -1 in any other case.
+
+ \sa gaiaIsValidXmlBlob, gaiaIsSchemaValidatedXmlBlob, 
+ gaiaIsCompressedXmlBlob, gaiaIsIsoMetadataXmlBlob, 
+ gaiaIsSldSeVectorStyleXmlBlob, gaiaIsSldStyleXmlBlob,
+ gaiaIsSldSeRasterStyleXmlBlob, gaiaIsSvgXmlBlob, gaiaIsMapConfigXmlBlob
+ */
+    GAIAGEO_DECLARE int gaiaIsGpxXmlBlob (const unsigned char *blob, int size);
+
 /**
  Return another XmlBLOB buffer compressed / uncompressed
 
@@ -312,7 +378,7 @@ extern "C"
 						 int *out_size);
 
 /**
- Checks if a valid XmlBLOB buffer has succesfully passed a formal Schema validation or not
+ Checks if a valid XmlBLOB buffer has successfully passed a formal Schema validation or not
 
  \param blob pointer to the XmlBLOB buffer.
  \param size XmlBLOB's size (in bytes).
@@ -322,10 +388,11 @@ extern "C"
 
  \sa gaiaIsValidXmlBlob, gaiaIsSvgXmlBlob, 
  gaiaIsCompressedXmlBlob, gaiaIsIsoMetadataXmlBlob, 
- gaiaIsSldSeVectorStyleXmlBlob, gaiaIsSldSeRasterStyleXmlBlob
+ gaiaIsSldSeVectorStyleXmlBlob, gaiaIsSldSeRasterStyleXmlBlob,
+ gaiaIsSldStyleXmlBlob, gaiaIsMapConfigXmlBlob 
  */
-    GAIAGEO_DECLARE int gaiaIsSchemaValidatedXmlBlob (const unsigned char *blob,
-						      int size);
+    GAIAGEO_DECLARE int gaiaIsSchemaValidatedXmlBlob (const unsigned char
+						      *blob, int size);
 
 /**
  Return the XMLDocument size (in bytes) from a valid XmlBLOB buffer
@@ -371,9 +438,9 @@ extern "C"
  \note the returned SchemaURI corresponds to dynamically allocated memory:
  so you are responsible to free() it before or after.
  */
-    GAIAGEO_DECLARE char *gaiaXmlGetInternalSchemaURI (void *p_cache,
-						       const unsigned char *xml,
-						       int xml_len);
+    GAIAGEO_DECLARE char *gaiaXmlGetInternalSchemaURI (const void *p_cache,
+						       const unsigned char
+						       *xml, int xml_len);
 
 /**
  Return the FileIdentifier from a valid XmlBLOB buffer
@@ -426,8 +493,9 @@ extern "C"
  \note the output XmlBLOB corresponds to dynamically allocated memory:
  so you are responsible to free() it before or after.
  */
-    GAIAGEO_DECLARE int gaiaXmlBlobSetFileId (void *p_cache, const unsigned char
-					      *blob, int size,
+    GAIAGEO_DECLARE int gaiaXmlBlobSetFileId (const void *p_cache,
+					      const unsigned char *blob,
+					      int size,
 					      const char *identifier,
 					      unsigned char **new_blob,
 					      int *new_size);
@@ -449,7 +517,7 @@ extern "C"
  \note the returned XmlBLOB corresponds to dynamically allocated memory:
  so you are responsible to free() it before or after.
  */
-    GAIAGEO_DECLARE int gaiaXmlBlobSetParentId (void *p_cache,
+    GAIAGEO_DECLARE int gaiaXmlBlobSetParentId (const void *p_cache,
 						const unsigned char *blob,
 						int size,
 						const char *identifier,
@@ -477,8 +545,9 @@ extern "C"
  \note the output XmlBLOB corresponds to dynamically allocated memory:
  so you are responsible to free() it before or after.
  */
-    GAIAGEO_DECLARE int gaiaXmlBlobAddFileId (void *p_cache, const unsigned char
-					      *blob, int size,
+    GAIAGEO_DECLARE int gaiaXmlBlobAddFileId (const void *p_cache,
+					      const unsigned char *blob,
+					      int size,
 					      const char *identifier,
 					      const char *ns_id,
 					      const char *uri_id,
@@ -508,7 +577,7 @@ extern "C"
  \note the returned XmlBLOB corresponds to dynamically allocated memory:
  so you are responsible to free() it before or after.
  */
-    GAIAGEO_DECLARE int gaiaXmlBlobAddParentId (void *p_cache,
+    GAIAGEO_DECLARE int gaiaXmlBlobAddParentId (const void *p_cache,
 						const unsigned char *blob,
 						int size,
 						const char *identifier,
@@ -519,6 +588,24 @@ extern "C"
 						unsigned char **new_blob,
 						int *new_size);
 
+/**
+ Return the Name from a valid XmlBLOB buffer
+
+ \param blob pointer to the XmlBLOB buffer.
+ \param size XmlBLOB's size (in bytes).
+
+ \return the Name for any valid XmlBLOB containing a Name; 
+  NULL in any other case.
+
+ \sa gaiaIsIsoMetadataXmlBlob, gaiaIsSldSeVectorStyleXmlBlob, 
+ gaiaIsSldSeRasterStyleXmlBlob, gaiaIsSldStyleXmlBlob
+
+ \note the returned Name corresponds to dynamically allocated memory:
+ so you are responsible to free() it before or after.
+ */
+    GAIAGEO_DECLARE char *gaiaXmlBlobGetName (const unsigned char
+					      *blob, int size);
+
 /**
  Return the Title from a valid XmlBLOB buffer
 
@@ -529,7 +616,7 @@ extern "C"
   NULL in any other case.
 
  \sa gaiaIsIsoMetadataXmlBlob, gaiaIsSldSeVectorStyleXmlBlob, 
- gaiaIsSldSeRasterStyleXmlBlob
+ gaiaIsSldSeRasterStyleXmlBlob, gaiaIsSldStyleXmlBlob
 
  \note the returned Title corresponds to dynamically allocated memory:
  so you are responsible to free() it before or after.
@@ -547,7 +634,7 @@ extern "C"
   NULL in any other case.
 
  \sa gaiaIsIsoMetadataXmlBlob, gaiaIsSldSeVectorStyleXmlBlob, 
- gaiaIsSldSeRasterStyleXmlBlob
+ gaiaIsSldSeRasterStyleXmlBlob, gaiaIsSldStyleXmlBlob
 
  \note the returned Abstract corresponds to dynamically allocated memory:
  so you are responsible to free() it before or after.
@@ -556,19 +643,19 @@ extern "C"
 						  *blob, int size);
 
 /**
- Return the Geometry Buffer from a valid XmlBLOB buffer
+ Return the Geometry buffer from a valid XmlBLOB buffer
 
  \param blob pointer to the XmlBLOB buffer.
  \param size XmlBLOB's size (in bytes).
  \param blob_geom on completion this variable will contain
- a pointer to the returned Geometry Buffer (NULL if no Geometry
+ a pointer to the returned Geometry buffer (NULL if no Geometry
  was defined within the XmlBLOB)
  \param blob_size on completion this variable will contain
- the size (in bytes) of the returned Geometry Buffer
+ the size (in bytes) of the returned Geometry buffer
 
  \sa gaiaIsIsoMetadataXmlBlob
 
- \note the returned Geometry Buffer corresponds to dynamically allocated memory:
+ \note the returned Geometry buffer corresponds to dynamically allocated memory:
  so you are responsible to free() it before or after.
  */
     GAIAGEO_DECLARE void gaiaXmlBlobGetGeometry (const unsigned char
@@ -576,6 +663,26 @@ extern "C"
 						 unsigned char **blob_geom,
 						 int *blob_size);
 
+/**
+ Return a MultiLinestring Geometry from a valid GPX XmlBLOB buffer
+
+ \param blob pointer to the XmlBLOB buffer.
+ \param size XmlBLOB's size (in bytes).
+ \param db_handle handle to the current SQLite connection
+ 
+ \return a Geometry of the MultiLinestring type, or NULL
+
+ \sa gaiaIsIsoMetadataXmlBlob
+
+ \note the returned Geometry corresponds to dynamically allocated memory:
+ so you are responsible to free() it before or after.
+ */
+    GAIAGEO_DECLARE gaiaGeomCollPtr gaiaXmlBlobMLineFromGPX (const unsigned
+							     char *blob,
+							     int size,
+							     sqlite3 *
+							     db_handle);
+
 /**
  Return the Charset Encoding from a valid XmlBLOB buffer
 
@@ -605,7 +712,7 @@ extern "C"
  \note the returned error/warning message corresponds to dynamically allocated memory:
  so you are responsible to free() it before or after.
  */
-    GAIAGEO_DECLARE char *gaiaXmlBlobGetLastParseError (void *p_cache);
+    GAIAGEO_DECLARE char *gaiaXmlBlobGetLastParseError (const void *p_cache);
 
 /**
  Return the most recent XML Validate error/warning (if any)
@@ -621,7 +728,7 @@ extern "C"
  \note the returned error/warning message corresponds to dynamically allocated memory:
  so you are responsible to free() it before or after.
  */
-    GAIAGEO_DECLARE char *gaiaXmlBlobGetLastValidateError (void *p_cache);
+    GAIAGEO_DECLARE char *gaiaXmlBlobGetLastValidateError (const void *p_cache);
 
 /**
  Checks if a Text string could be a valid XPathExpression
@@ -634,7 +741,7 @@ extern "C"
 
  \sa gaiaXmlBlobGetLastXPathError
  */
-    GAIAGEO_DECLARE int gaiaIsValidXPathExpression (void *p_cache,
+    GAIAGEO_DECLARE int gaiaIsValidXPathExpression (const void *p_cache,
 						    const char *xpath_expr);
 
 /**
@@ -651,7 +758,7 @@ extern "C"
  \note the returned error/warning message corresponds to dynamically allocated memory:
  so you are responsible to free() it before or after.
  */
-    GAIAGEO_DECLARE char *gaiaXmlBlobGetLastXPathError (void *p_cache);
+    GAIAGEO_DECLARE char *gaiaXmlBlobGetLastXPathError (const void *p_cache);
 
 /**
  Load an external XML Document
@@ -669,7 +776,8 @@ extern "C"
  so you are responsible to free() it [unless SQLite will take care
  of memory cleanup via buffer binding].
  */
-    GAIAGEO_DECLARE int gaiaXmlLoad (void *p_cache, const char *path_or_url,
+    GAIAGEO_DECLARE int gaiaXmlLoad (const void *p_cache,
+				     const char *path_or_url,
 				     unsigned char **result, int *size,
 				     char **parsing_errors);
 
