@@ -2,7 +2,7 @@
 
  mbrcache.c -- SQLite3 extension [MBR CACHE VIRTUAL TABLE]
 
- version 4.1, 2013 May 8
+ version 5.0, 2020 August 1
 
  Author: Sandro Furieri a.furieri@lqt.it
 
@@ -24,7 +24,7 @@ The Original Code is the SpatiaLite library
 
 The Initial Developer of the Original Code is Alessandro Furieri
  
-Portions created by the Initial Developer are Copyright (C) 2008-2013
+Portions created by the Initial Developer are Copyright (C) 2008-2021
 the Initial Developer. All Rights Reserved.
 
 Contributor(s):
@@ -58,7 +58,7 @@ the terms of any one of the MPL, the GPL or the LGPL.
 #include <spatialite/sqlite.h>
 #include <spatialite/debug.h>
 
-#include <spatialite/spatialite.h>
+#include <spatialite/spatialite_ext.h>
 #include <spatialite/gaiageo.h>
 #include <spatialite/gaiaaux.h>
 
@@ -1525,7 +1525,8 @@ sqlite3MbrCacheInit (sqlite3 * db)
 }
 
 int
-mbrcache_extension_init (sqlite3 * db)
+mbrcache_extension_init (void *xdb)
 {
+    sqlite3 *db = (sqlite3 *) xdb;
     return sqlite3MbrCacheInit (db);
 }
