@@ -24,7 +24,7 @@ The Original Code is the SpatiaLite library
 
 The Initial Developer of the Original Code is Alessandro Furieri
  
-Portions created by the Initial Developer are Copyright (C) 2008-2020
+Portions created by the Initial Developer are Copyright (C) 2008-2021
 the Initial Developer. All Rights Reserved.
 
 Contributor(s):
@@ -61,7 +61,7 @@ the terms of any one of the MPL, the GPL or the LGPL.
 #include <spatialite/sqlite.h>
 #include <spatialite/debug.h>
 
-#include <spatialite/spatialite.h>
+#include <spatialite/spatialite_ext.h>
 #include <spatialite/gaiaaux.h>
 #include <spatialite/gaiageo.h>
 
@@ -1054,7 +1054,11 @@ gaiaTextReaderAlloc (const char *path, char field_separator,
 /* allocating the main TXT-Reader */
     int col;
     gaiaTextReaderPtr reader;
+#ifdef _WIN32
+    FILE *in = gaia_win_fopen (path, "rb");	/* opening the input file */
+#else
     FILE *in = fopen (path, "rb");	/* opening the input file */
+#endif
     if (in == NULL)
 	return NULL;
 
