@@ -46,11 +46,13 @@ the terms of any one of the MPL, the GPL or the LGPL.
 #include <stdio.h>
 #include <string.h>
 
-#include "config.h"
+#include <spatialite/gaiaconfig.h>
 
 #include "sqlite3.h"
 #include "spatialite.h"
 
+#ifndef OMIT_ICONV		/* only if ICONV is supported */
+
 static int
 do_test (sqlite3 * handle, const void *p_cache)
 {
@@ -59,11 +61,11 @@ do_test (sqlite3 * handle, const void *p_cache)
     int row_count;
 
     ret =
-	sqlite3_exec (handle, "SELECT InitSpatialMetadata(1)", NULL, NULL,
+	sqlite3_exec (handle, "SELECT InitSpatialMetadataFull(1)", NULL, NULL,
 		      &err_msg);
     if (ret != SQLITE_OK)
       {
-	  fprintf (stderr, "InitSpatialMetadata() error: %s\n", err_msg);
+	  fprintf (stderr, "InitSpatialMetadataFull() error: %s\n", err_msg);
 	  sqlite3_free (err_msg);
 	  sqlite3_close (handle);
 	  return -2;
@@ -78,7 +80,7 @@ do_test (sqlite3 * handle, const void *p_cache)
 	  return -3;
       }
 
-#ifdef ENABLE_LWGEOM		/* only if LWGEOM is supported */
+#ifdef ENABLE_RTTOPO		/* only if RTTOPO is supported */
 
     if (p_cache == NULL)
 	ret =
@@ -144,10 +146,12 @@ do_test (sqlite3 * handle, const void *p_cache)
 	  return -7;
       }
 
-#endif /* end LWGEOM conditionals */
+#endif /* end RTTOPO conditionals */
     return 0;
 }
 
+#endif
+
 int
 main (int argc, char *argv[])
 {
@@ -156,9 +160,6 @@ main (int argc, char *argv[])
     sqlite3 *handle;
     void *cache = spatialite_alloc_connection ();
 
-    if (argc > 1 || argv[0] == NULL)
-	argc = 1;		/* silencing stupid compiler warnings */
-
     ret =
 	sqlite3_open_v2 (":memory:", &handle,
 			 SQLITE_OPEN_READWRITE | SQLITE_OPEN_CREATE, NULL);
@@ -214,6 +215,9 @@ main (int argc, char *argv[])
     spatialite_cleanup ();
 #endif /* end ICONV conditional */
 
+    if (argc > 1 || argv[0] == NULL)
+	argc = 1;		/* silencing stupid compiler warnings */
+
     spatialite_shutdown ();
     return 0;
 }
