@@ -46,11 +46,13 @@ the terms of any one of the MPL, the GPL or the LGPL.
 #include <string.h>
 #include <math.h>
 
-#include "config.h"
+#include <spatialite/gaiaconfig.h>
 
 #include "sqlite3.h"
 #include "spatialite.h"
 
+#ifndef OMIT_ICONV		/* only if ICONV is supported */
+
 static int
 do_test (sqlite3 * handle, const void *p_cache)
 {
@@ -65,11 +67,11 @@ do_test (sqlite3 * handle, const void *p_cache)
     gaiaVectorLayersListPtr list;
 
     ret =
-	sqlite3_exec (handle, "SELECT InitSpatialMetadata(1)", NULL, NULL,
+	sqlite3_exec (handle, "SELECT InitSpatialMetadataFull(1)", NULL, NULL,
 		      &err_msg);
     if (ret != SQLITE_OK)
       {
-	  fprintf (stderr, "InitSpatialMetadata() error: %s\n", err_msg);
+	  fprintf (stderr, "InitSpatialMetadataFull() error: %s\n", err_msg);
 	  sqlite3_free (err_msg);
 	  sqlite3_close (handle);
 	  return -2;
@@ -672,7 +674,7 @@ do_test (sqlite3 * handle, const void *p_cache)
 				 GAIA_VECTORS_LIST_OPTIMISTIC);
     gaiaFreeVectorLayersList (list);
 
-#ifdef ENABLE_LWGEOM		/* only if LWGEOM is supported */
+#ifdef ENABLE_RTTOPO		/* only if RTTOPO is supported */
 
     if (p_cache == NULL)
 	ret = check_all_geometry_columns (handle, "./report", NULL, NULL);
@@ -702,7 +704,7 @@ do_test (sqlite3 * handle, const void *p_cache)
 	  return -62;
       }
 
-#endif /* end LWGEOM conditionals */
+#endif /* end RTTOPO conditionals */
 
 /* checking gaiaGetVectorLayersList() - Table */
     list =
@@ -719,6 +721,8 @@ do_test (sqlite3 * handle, const void *p_cache)
     return 0;
 }
 
+#endif
+
 int
 main (int argc, char *argv[])
 {
@@ -786,6 +790,9 @@ main (int argc, char *argv[])
       }
 #endif /* end ICONV conditional */
 
+    if (argc > 1 || argv[0] == NULL)
+	argc = 1;		/* silencing stupid compiler warnings */
+
     spatialite_shutdown ();
     return 0;
 }
