@@ -45,7 +45,7 @@ the terms of any one of the MPL, the GPL or the LGPL.
 #include <stdio.h>
 #include <string.h>
 
-#include "config.h"
+#include <spatialite/gaiaconfig.h>
 
 #include "sqlite3.h"
 #include "spatialite.h"
@@ -56,10 +56,10 @@ main (int argc, char *argv[])
     if (argc > 1 || argv[0] == NULL)
 	argc = 1;		/* silencing stupid compiler warnings */
 
-    if (strcmp (spatialite_version (), VERSION) != 0)
+    if (strcmp (spatialite_version (), SPATIALITE_VERSION) != 0)
       {
 	  fprintf (stderr, "SpatiaLite version mismatch: %s and %s\n",
-		   VERSION, spatialite_version ());
+		   SPATIALITE_VERSION, spatialite_version ());
 	  return -1;
       }
 
